@@ -33,7 +33,12 @@ class NotFoundError(JsonapiError):
     message = "NotFoundError "
 
     def __init__(self, message="", status_code=HTTPStatus.NOT_FOUND.value, api_code=None):
-        Exception.__init__(self)
+        """
+        :param message: Message to be returned in the (json) body
+        :param status_code: HTTP Status code
+        :param api_code: API code
+        """
+        JsonapiError.__init__(self)
         self.status_code = status_code
         safrs.log.error("Not found: %s", message)
         if is_debug():
@@ -74,7 +79,7 @@ class GenericError(JsonapiError):
         self.status_code = status_code
         safrs.log.error("Generic Error: %s", message)
         if is_debug():
-            safrs.log.info("Error in {}".format(request.url))
+            safrs.log.info(f"Error in {request.url}")
             safrs.log.debug(traceback.format_exc(120))
             self.message += str(message)
         else:
