@@ -58,7 +58,7 @@ class SAFRSID:
             try:
                 result = cls.columns[0].type.python_type(id)
             except Exception:
-                raise ValidationError("Invalid id: '{}'.".format(id))
+                raise ValidationError(f"Invalid id: '{id}'.")
         else:
             pass
             # safrs.log.debug("ID Validation not implemented for {}".format(cls))
@@ -84,20 +84,20 @@ class SAFRSID:
         return getattr(obj, cls.primary_keys[0])
 
     @classmethod
-    def get_pks(cls, id):
+    def get_pks(cls, jsonapi_id):
         """
-        Convert the id string to a pk dict
-        id is a jsonapi_id, in case the PK is composite it consists of PKs joined by cls.delimiter
+        Convert the jsonapi_id string to a pk dict
+        in case the PK is composite it consists of PKs joined by cls.delimiter
         Note: there may be an issue when the cls.delimiter is contained in an id
         :return: primary key dict
         """
         if len(cls.columns) == 1:
-            values = [id]
+            values = [jsonapi_id]
         else:
-            values = str(id).split(cls.delimiter)
+            values = str(jsonapi_id).split(cls.delimiter)
         if len(values) != len(cls.columns):
-            columns = [ c.name for c in cls.columns ]
-            raise ValidationError("PK values ({}) do not match columns ({})".format(values, columns))
+            columns = [c.name for c in cls.columns]
+            raise ValidationError(f"PK values ({values}) do not match columns ({columns})")
         result = dict()
         for pk_col, val in zip(cls.columns, values):
             if not val:
@@ -115,7 +115,7 @@ class SAFRSID:
                 else:
                     result[col_name] = ""
             except Exception as exc:  # pragma: no cover
-                safrs.log.warning("PK Error: {}".format(exc))
+                safrs.log.warning(f"PK Error: {exc}")
                 result[col_name] = ""
 
         return result
@@ -133,8 +133,8 @@ class SAFRSID:
         Extract the primary keys from kw_dict (these are the kwargs passed to SAFRSBase.new())
         In case of composite keys we construct the jsonapi_id by using the delimiter to join the values
         :return: primary keys dict
-        """ 
-        pks = { k : str(kw_dict[k]) for k in cls.column_names }
+        """
+        pks = {k: str(kw_dict[k]) for k in cls.column_names}
         id = cls.delimiter.join(pks.values())
         return cls.get_pks(id)
 
@@ -255,6 +255,6 @@ class UUIDType(TypeDecorator):  # pragma: no cover
         try:
             uuid.UUID(value, version=4)
         except Exception as exc:
-            raise ValidationError("UUID Validation Error {} ({})".format(value, exc))
+            raise ValidationError(f"UUID Validation Error {value} ({exc})")
 
         return value
